@@ -12,6 +12,43 @@ import (
 	"gopkg.in/yaml.v3"
 )
 
+// TextInput reads a file (or stdin) as raw text and returns the contents as a string.
+// It does not parse the contents — the file is treated as opaque text.
+// Use f="-" to read from stdin, or pass a file path.
+func TextInput(f string) (string, error) {
+	var reader io.Reader
+	if f == "-" {
+		reader = os.Stdin
+	} else if f != "" {
+		fp, err := os.Open(f)
+		if err != nil {
+			return "", err
+		}
+		defer func() {
+			_ = fp.Close()
+		}()
+
+		info, err := fp.Stat()
+		if err != nil {
+			return "", err
+		}
+
+		if info.IsDir() {
+			return "", fmt.Errorf("text mode does not support directories: %s", f)
+		}
+
+		reader = fp
+	} else {
+		return "", fmt.Errorf("Nothing to read: No file specified")
+	}
+
+	data, err := io.ReadAll(reader)
+	if err != nil {
+		return "", err
+	}
+	return string(data), nil
+}
+
 func Inputs(f string) ([]yaml.Node, error) {
 	var reader io.Reader
 	if f == "-" {
