@@ -10,6 +10,7 @@ import (
 	"github.com/helmfile/vals/pkg/providers/azurekeyvault"
 	"github.com/helmfile/vals/pkg/providers/conjur"
 	"github.com/helmfile/vals/pkg/providers/doppler"
+	execprovider "github.com/helmfile/vals/pkg/providers/exec"
 	"github.com/helmfile/vals/pkg/providers/gcpsecrets"
 	"github.com/helmfile/vals/pkg/providers/gcs"
 	"github.com/helmfile/vals/pkg/providers/gitlab"
@@ -48,7 +49,7 @@ func New(l *log.Logger, provider api.StaticConfig, awsLogLevel string) (api.Lazy
 	case "awssecrets":
 		return awssecrets.New(l, provider, awsLogLevel), nil
 	case "sops":
-		return sops.New(l, provider), nil
+		return sops.New(l, provider, awsLogLevel), nil
 	case "gcpsecrets":
 		return gcpsecrets.New(provider), nil
 	case "tfstate":
@@ -91,6 +92,8 @@ func New(l *log.Logger, provider api.StaticConfig, awsLogLevel string) (api.Lazy
 		return secretserver.New(provider)
 	case "infisical":
 		return infisical.New(l, provider), nil
+	case "exec":
+		return execprovider.New(l, provider), nil
 	}
 
 	return nil, fmt.Errorf("failed initializing string provider from config: %v", provider)
