@@ -28,6 +28,7 @@ import (
 	"github.com/helmfile/vals/pkg/providers/doppler"
 	"github.com/helmfile/vals/pkg/providers/echo"
 	"github.com/helmfile/vals/pkg/providers/envsubst"
+	execprovider "github.com/helmfile/vals/pkg/providers/exec"
 	"github.com/helmfile/vals/pkg/providers/file"
 	"github.com/helmfile/vals/pkg/providers/gcpsecrets"
 	"github.com/helmfile/vals/pkg/providers/gcs"
@@ -90,6 +91,7 @@ const (
 	ProviderSecretsManager     = "awssecrets"
 	ProviderSOPS               = "sops"
 	ProviderEcho               = "echo"
+	ProviderExec               = "exec"
 	ProviderFile               = "file"
 	ProviderGCPSecretManager   = "gcpsecrets"
 	ProviderGoogleSheets       = "googlesheets"
@@ -228,7 +230,7 @@ func (r *Runtime) prepare() (*expansion.ExpandRegexMatch, error) {
 			p := oci.New(r.logger, conf)
 			return p, nil
 		case ProviderSOPS:
-			p := sops.New(r.logger, conf)
+			p := sops.New(r.logger, conf, r.Options.AWSLogLevel)
 			return p, nil
 		case ProviderEcho:
 			p := echo.New(conf)
@@ -311,6 +313,9 @@ func (r *Runtime) prepare() (*expansion.ExpandRegexMatch, error) {
 		case ProviderServercore:
 			p := servercore.New(r.logger, conf)
 			return p, nil
+		case ProviderExec:
+			p := execprovider.New(r.logger, conf)
+			return p, nil
 		}
 		return nil, fmt.Errorf("no provider registered for scheme %q", scheme)
 	}
@@ -349,10 +354,46 @@ func (r *Runtime) prepare() (*expansion.ExpandRegexMatch, error) {
 				}
 			}
 
-			uri, err := url.Parse(key)
+			// Handle ARN-based URIs which contain colons that would be misinterpreted as port separators.
+			// ARN examples: arn:aws:service:region:account:resource (standard), arn:aws-cn:..., arn:aws-us-gov:...
+			// We need to detect and transform the ARN to avoid URL parsing issues with colons across AWS partitions.
+			processedKey := key
+			arnValue := ""
+
+			// Check if this looks like an ARN-based URI (ARN immediately follows "://")
+			if schemeEnd := strings.Index(key, "://"); schemeEnd != -1 {
+				afterScheme := key[schemeEnd+3:]
+				if strings.HasPrefix(afterScheme, "arn:aws:") || strings.HasPrefix(afterScheme, "arn:aws-") {
+					prefix := key[:schemeEnd+3] // includes "://"
+					remainder := afterScheme
+
+					// Find where the ARN ends (at ? for query params, # for fragment, or end of string)
+					arnEnd := len(remainder)
+					if idx := strings.IndexAny(remainder, "?#"); idx != -1 {
+						arnEnd = idx
+					}
+
+					arnValue = remainder[:arnEnd]
+					suffix := remainder[arnEnd:]
+
+					// Temporarily transform to a triple-slash format so the ARN is kept in the path.
+					// This avoids net/url interpreting colons in the ARN as port separators; after parsing,
+					// we move the ARN from the path into the host field (see logic below).
+					processedKey = prefix + "/" + arnValue + suffix
+				}
+			}
+
+			uri, err := url.Parse(processedKey)
 			if err != nil {
 				return nil, err
 			}
+			// If we processed an ARN, restore it directly from the original value
+			if arnValue != "" {
+				// Use the exact ARN string captured before parsing to avoid net/url normalization/decoding.
+				uri.Host = arnValue
+				uri.Path = ""
+				uri.RawPath = ""
+			}
 
 			hash := uriToProviderHash(uri)
 
@@ -535,6 +576,7 @@ var KnownValuesTypes = []string{
 	ProviderTFState,
 	ProviderFile,
 	ProviderEcho,
+	ProviderExec,
 	ProviderKeychain,
 	ProviderEnvSubst,
 	ProviderPulumiStateAPI,
